# Copyright 2015, Thales Services SAS
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from django.utils.translation import ugettext_lazy as _

from openstack_dashboard.dashboards.project.routers.extensions.extraroutes\
    import tables as routes_table


class AdminRouterRoutesTable(routes_table.ExtraRoutesTable):

    class Meta(object):
        # Redefine Meta class to disable action (admin)
        name = "extra_routes"
        verbose_name = _("Static Routes")
